==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Odplatnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Odplatnosc extends GenericDPSObject {
    /**
     * ODPLATNOSC.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ODPLATNOSC.DECYZJA_KIERUJACA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long decyzjaKierujacaId;

    /**
     * ODPLATNOSC.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * ODPLATNOSC.EWIDENCJA_ZGON_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaZgonId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPLATNOSC.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODPLATNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODPLATNOSC.DECYZJA_KIERUJACA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDecyzjaKierujacaId() {
        return decyzjaKierujacaId;
    }

    /**
     * ODPLATNOSC.DECYZJA_KIERUJACA_ID
     *
     * @param decyzjaKierujacaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDecyzjaKierujacaId(Long decyzjaKierujacaId) {
        this.decyzjaKierujacaId = decyzjaKierujacaId;
    }

    /**
     * @return ODPLATNOSC.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * ODPLATNOSC.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return ODPLATNOSC.EWIDENCJA_ZGON_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaZgonId() {
        return ewidencjaZgonId;
    }

    /**
     * ODPLATNOSC.EWIDENCJA_ZGON_ID
     *
     * @param ewidencjaZgonId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaZgonId(Long ewidencjaZgonId) {
        this.ewidencjaZgonId = ewidencjaZgonId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Odplatnosc other = (Odplatnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDecyzjaKierujacaId() == null ? other.getDecyzjaKierujacaId() == null : this.getDecyzjaKierujacaId().equals(other.getDecyzjaKierujacaId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getEwidencjaZgonId() == null ? other.getEwidencjaZgonId() == null : this.getEwidencjaZgonId().equals(other.getEwidencjaZgonId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDecyzjaKierujacaId() == null) ? 0 : getDecyzjaKierujacaId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getEwidencjaZgonId() == null) ? 0 : getEwidencjaZgonId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", decyzjaKierujacaId=").append(decyzjaKierujacaId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", ewidencjaZgonId=").append(ewidencjaZgonId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Odplatnosc.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Odplatnosc extends GenericDPSObject {
    /**
     * ODPLATNOSC.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ODPLATNOSC.DECYZJA_KIERUJACA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long decyzjaKierujacaId;

    /**
     * ODPLATNOSC.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * ODPLATNOSC.EWIDENCJA_ZGON_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaZgonId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPLATNOSC.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ODPLATNOSC.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ODPLATNOSC.DECYZJA_KIERUJACA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDecyzjaKierujacaId() {
        return decyzjaKierujacaId;
    }

    /**
     * ODPLATNOSC.DECYZJA_KIERUJACA_ID
     *
     * @param decyzjaKierujacaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDecyzjaKierujacaId(Long decyzjaKierujacaId) {
        this.decyzjaKierujacaId = decyzjaKierujacaId;
    }

    /**
     * @return ODPLATNOSC.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * ODPLATNOSC.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return ODPLATNOSC.EWIDENCJA_ZGON_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaZgonId() {
        return ewidencjaZgonId;
    }

    /**
     * ODPLATNOSC.EWIDENCJA_ZGON_ID
     *
     * @param ewidencjaZgonId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaZgonId(Long ewidencjaZgonId) {
        this.ewidencjaZgonId = ewidencjaZgonId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Odplatnosc other = (Odplatnosc) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDecyzjaKierujacaId() == null ? other.getDecyzjaKierujacaId() == null : this.getDecyzjaKierujacaId().equals(other.getDecyzjaKierujacaId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getEwidencjaZgonId() == null ? other.getEwidencjaZgonId() == null : this.getEwidencjaZgonId().equals(other.getEwidencjaZgonId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDecyzjaKierujacaId() == null) ? 0 : getDecyzjaKierujacaId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getEwidencjaZgonId() == null) ? 0 : getEwidencjaZgonId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", decyzjaKierujacaId=").append(decyzjaKierujacaId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", ewidencjaZgonId=").append(ewidencjaZgonId);
        sb.append("]");
        return sb.toString();
    }
}
